=================================
Flask ApiDoc
=================================
Flask ApiDoc is a Flask extension which adds support for the ApiDoc_.

|Version|

Documentation
===============
Soon... take a look at the examples_ to see how it works.

Installation
===============
You can install flask-apidoc via Python Package Index (PyPI_),::

    $ pip install flask-apidoc

Feedback
===============
Please use the Issues_ for feature requests and troubleshooting usage.

.. |Version| image:: https://badge.fury.io/py/flask-apscheduler.svg?
   :target: http://badge.fury.io/py/flask-apidoc

.. |Downloads| image:: https://pypip.in/d/flask-apscheduler/badge.svg?
   :target: https://pypi.python.org/pypi/flask-apidoc
   
.. |License| image:: https://pypip.in/license/flask-apscheduler/badge.svg?
   :target: https://github.com/viniciuschiele/flask-apidoc/blob/master/LICENSE

.. _ApiDoc: http://www.apidocjs.com

.. _examples: https://github.com/viniciuschiele/flask-apidoc/tree/master/examples

.. _PyPi: https://pypi.python.org/pypi/flask-apidoc

.. _Issues: https://github.com/viniciuschiele/flask-apidoc/issues
